@@ -1,7 +1,7 @@
 from authentication_error import AuthenticationError
 from authorization_error import AuthorizationError
 from down_for_maintenance_error import DownForMaintenanceError
-from forged_query_string import ForgedQueryStringError
+from forged_query_string_error import ForgedQueryStringError
 from not_found_error import NotFoundError
 from server_error import ServerError
 from unexpected_error import UnexpectedError
